@@ -4,10 +4,10 @@ Classes for querying the information in a test coverage report.
 
 import itertools
 import os
-import posixpath
 import re
 from collections import defaultdict
 
+from diff_cover import util
 from diff_cover.command_runner import run_command_for_code
 from diff_cover.git_path import GitPathTool
 from diff_cover.violationsreporters.base import (
@@ -37,21 +37,6 @@ class XmlCoverageReporter(BaseViolationReporter):
 
         self._src_roots = src_roots or [""]
 
-    @staticmethod
-    def _to_unix_path(path):
-        """
-        Tries to ensure tha the path is a normalized unix path.
-        This seems to be the solution cobertura used....
-        https://github.com/cobertura/cobertura/blob/642a46eb17e14f51272c6962e64e56e0960918af/cobertura/src/main/java/net/sourceforge/cobertura/instrument/ClassPattern.java#L84
-
-        I know of at least one case where this will fail (\\) is allowed in unix paths.
-        But I am taking the bet that this is not common. We deal with source code.
-
-        :param path: string of the path to convert
-        :return: the unix version of that path
-        """
-        return posixpath.normpath(os.path.normcase(path).replace("\\", "/"))
-
     def _get_classes(self, xml_document, src_path):
         """
         Given a path and parsed xml_document provides class nodes
@@ -70,12 +55,12 @@ class XmlCoverageReporter(BaseViolationReporter):
         # If cwd is `/home/user/work/diff-cover/diff_cover`
         # and src_path is `diff_cover/violations_reporter.py`
         # search for `violations_reporter.py`
-        src_rel_path = self._to_unix_path(GitPathTool.relative_path(src_path))
+        src_rel_path = util.to_unix_path(GitPathTool.relative_path(src_path))
 
         # If cwd is `/home/user/work/diff-cover/diff_cover`
         # and src_path is `other_package/some_file.py`
         # search for `/home/user/work/diff-cover/other_package/some_file.py`
-        src_abs_path = self._to_unix_path(GitPathTool.absolute_path(src_path))
+        src_abs_path = util.to_unix_path(GitPathTool.absolute_path(src_path))
 
         # cobertura sometimes provides the sources for the measurements
         # within it. If we have that we outta use it
@@ -89,7 +74,7 @@ class XmlCoverageReporter(BaseViolationReporter):
                 for clazz in classes
                 if src_abs_path
                 in [
-                    self._to_unix_path(
+                    util.to_unix_path(
                         os.path.join(source.strip(), clazz.get("filename"))
                     )
                     for source in sources
@@ -98,12 +83,12 @@ class XmlCoverageReporter(BaseViolationReporter):
             or [
                 clazz
                 for clazz in classes
-                if self._to_unix_path(clazz.get("filename")) == src_abs_path
+                if util.to_unix_path(clazz.get("filename")) == src_abs_path
             ]
             or [
                 clazz
                 for clazz in classes
-                if self._to_unix_path(clazz.get("filename")) == src_rel_path
+                if util.to_unix_path(clazz.get("filename")) == src_rel_path
             ]
         )
 
@@ -450,6 +435,8 @@ class PylintDriver(QualityDriver):
 
                     for violation in files_involved:
                         pylint_src_path, line_number = violation
+                        # pylint might uses windows paths
+                        pylint_src_path = util.to_unix_path(pylint_src_path)
                         # If we're looking for a particular source file,
                         # ignore any other source files.
                         if function_name:
